@@ -2,31 +2,143 @@
 
 import copy
 import itertools
+import operator
 import os
-from collections import Set, namedtuple
+import sys
+from collections import namedtuple
+from collections.abc import Set
+from configparser import NoOptionError, NoSectionError, RawConfigParser
+from functools import reduce
 from re import compile as re
 
-
-try:  # Python 3.x
-    from ConfigParser import RawConfigParser
-except ImportError:  # Python 2.x
-    from configparser import RawConfigParser
-
-
-from .utils import __version__, log
+from ._version import __version__
+from .utils import log
 from .violations import ErrorRegistry, conventions
 
+if sys.version_info >= (3, 11):
+    import tomllib
+else:
+    try:
+        import tomli as tomllib
+    except ImportError:  # pragma: no cover
+        tomllib = None  # type: ignore
+
 
 def check_initialized(method):
     """Check that the configuration object was initialized."""
+
     def _decorator(self, *args, **kwargs):
         if self._arguments is None or self._options is None:
             raise RuntimeError('using an uninitialized configuration')
         return method(self, *args, **kwargs)
+
     return _decorator
 
 
-class ConfigurationParser(object):
+class TomlParser:
+    """ConfigParser that partially mimics RawConfigParser but for toml files.
+
+    See RawConfigParser for more info. Also, please note that not all
+    RawConfigParser functionality is implemented, but only the subset that is
+    currently used by pydocstyle.
+    """
+
+    def __init__(self):
+        """Create a toml parser."""
+        self._config = {}
+
+    def read(self, filenames, encoding=None):
+        """Read and parse a filename or an iterable of filenames.
+
+        Files that cannot be opened are silently ignored; this is
+        designed so that you can specify an iterable of potential
+        configuration file locations (e.g. current directory, user's
+        home directory, systemwide directory), and all existing
+        configuration files in the iterable will be read.  A single
+        filename may also be given.
+
+        Return list of successfully read files.
+        """
+        if isinstance(filenames, (str, bytes, os.PathLike)):
+            filenames = [filenames]
+        read_ok = []
+        for filename in filenames:
+            try:
+                with open(filename, "rb") as fp:
+                    if not tomllib:
+                        log.warning(
+                            "The %s configuration file was ignored, "
+                            "because the `tomli` package is not installed.",
+                            filename,
+                        )
+                        continue
+                    self._config.update(tomllib.load(fp))
+            except OSError:
+                continue
+            if isinstance(filename, os.PathLike):
+                filename = os.fspath(filename)
+            read_ok.append(filename)
+        return read_ok
+
+    def _get_section(self, section, allow_none=False):
+        try:
+            current = reduce(
+                operator.getitem,
+                section.split('.'),
+                self._config['tool'],
+            )
+        except KeyError:
+            current = None
+
+        if isinstance(current, dict):
+            return current
+        elif allow_none:
+            return None
+        else:
+            raise NoSectionError(section)
+
+    def has_section(self, section):
+        """Indicate whether the named section is present in the configuration."""
+        return self._get_section(section, allow_none=True) is not None
+
+    def options(self, section):
+        """Return a list of option names for the given section name."""
+        current = self._get_section(section)
+        return list(current.keys())
+
+    def get(self, section, option, *, _conv=None):
+        """Get an option value for a given section."""
+        d = self._get_section(section)
+        option = option.lower()
+        try:
+            value = d[option]
+        except KeyError:
+            raise NoOptionError(option, section)
+
+        if isinstance(value, dict):
+            raise TypeError(
+                f"Expected {section}.{option} to be an option, not a section."
+            )
+
+        # toml should convert types automatically
+        # don't manually convert, just check, that the type is correct
+        if _conv is not None and not isinstance(value, _conv):
+            raise TypeError(
+                f"The type of {section}.{option} should be {_conv}"
+            )
+
+        return value
+
+    def getboolean(self, section, option):
+        """Get a boolean option value for a given section."""
+        return self.get(section, option, _conv=bool)
+
+    def getint(self, section, option):
+        """Get an integer option value for a given section."""
+        return self.get(section, option, _conv=int)
+
+
+class ConfigurationParser:
     """Responsible for parsing configuration from files and CLI.
 
     There are 2 types of configurations: Run configurations and Check
@@ -36,7 +148,7 @@ class ConfigurationParser(object):
     ------------------
     Responsible for deciding things that are related to the user interface and
     configuration discovery, e.g. verbosity, debug options, etc.
-    All run configurations default to `False` or `None` and are decided only 
+    All run configurations default to `False` or `None` and are decided only
     by CLI.
 
     Check Configurations:
@@ -64,14 +176,24 @@ class ConfigurationParser(object):
 
     """
 
-    CONFIG_FILE_OPTIONS = ('convention', 'select', 'ignore', 'add-select',
-                           'add-ignore', 'match', 'match-dir',
-                           'ignore-decorators')
+    CONFIG_FILE_OPTIONS = (
+        'convention',
+        'select',
+        'ignore',
+        'add-select',
+        'add-ignore',
+        'match',
+        'match-dir',
+        'ignore-decorators',
+    )
     BASE_ERROR_SELECTION_OPTIONS = ('ignore', 'select', 'convention')
 
-    DEFAULT_MATCH_RE = '(?!test_).*\.py'
-    DEFAULT_MATCH_DIR_RE = '[^\.].*'
+    DEFAULT_MATCH_RE = r'(?!test_).*\.py'
+    DEFAULT_MATCH_DIR_RE = r'[^\.].*'
     DEFAULT_IGNORE_DECORATORS_RE = ''
+    DEFAULT_PROPERTY_DECORATORS = (
+        "property,cached_property,functools.cached_property"
+    )
     DEFAULT_CONVENTION = conventions.pep257
 
     PROJECT_CONFIG_FILES = (
@@ -81,6 +203,7 @@ class ConfigurationParser(object):
         '.pydocstyle.ini',
         '.pydocstylerc',
         '.pydocstylerc.ini',
+        'pyproject.toml',
         # The following is deprecated, but remains for backwards compatibility.
         '.pep257',
     )
@@ -129,7 +252,7 @@ class ConfigurationParser(object):
     def get_files_to_check(self):
         """Generate files and error codes to check on each one.
 
-        Walk dir trees under `self._arguments` and generate yield filnames
+        Walk dir trees under `self._arguments` and yield file names
         that `match` under each directory that `match_dir`.
         The method locates the configuration for each file name and yields a
         tuple of (filename, [error_codes]).
@@ -138,54 +261,72 @@ class ConfigurationParser(object):
         might be raised.
 
         """
-        def _get_matches(config):
+
+        def _get_matches(conf):
             """Return the `match` and `match_dir` functions for `config`."""
-            match_func = re(config.match + '$').match
-            match_dir_func = re(config.match_dir + '$').match
+            match_func = re(conf.match + '$').match
+            match_dir_func = re(conf.match_dir + '$').match
             return match_func, match_dir_func
 
-        def _get_ignore_decorators(config):
+        def _get_ignore_decorators(conf):
             """Return the `ignore_decorators` as None or regex."""
-            if config.ignore_decorators:  # not None and not ''
-                ignore_decorators = re(config.ignore_decorators)
-            else:
-                ignore_decorators = None
-            return ignore_decorators
+            return (
+                re(conf.ignore_decorators) if conf.ignore_decorators else None
+            )
+
+        def _get_property_decorators(conf):
+            """Return the `property_decorators` as None or set."""
+            return (
+                set(conf.property_decorators.split(","))
+                if conf.property_decorators
+                else None
+            )
 
         for name in self._arguments:
             if os.path.isdir(name):
                 for root, dirs, filenames in os.walk(name):
-                    config = self._get_config(root)
+                    config = self._get_config(os.path.abspath(root))
                     match, match_dir = _get_matches(config)
                     ignore_decorators = _get_ignore_decorators(config)
+                    property_decorators = _get_property_decorators(config)
 
                     # Skip any dirs that do not match match_dir
-                    dirs[:] = [dir for dir in dirs if match_dir(dir)]
+                    dirs[:] = [d for d in dirs if match_dir(d)]
 
-                    for filename in filenames:
+                    for filename in map(os.path.basename, filenames):
                         if match(filename):
                             full_path = os.path.join(root, filename)
-                            yield (full_path, list(config.checked_codes),
-                                   ignore_decorators)
+                            yield (
+                                full_path,
+                                list(config.checked_codes),
+                                ignore_decorators,
+                                property_decorators,
+                            )
             else:
-                config = self._get_config(name)
+                config = self._get_config(os.path.abspath(name))
                 match, _ = _get_matches(config)
                 ignore_decorators = _get_ignore_decorators(config)
-                if match(name):
-                    yield (name, list(config.checked_codes), ignore_decorators)
+                property_decorators = _get_property_decorators(config)
+                if match(os.path.basename(name)):
+                    yield (
+                        name,
+                        list(config.checked_codes),
+                        ignore_decorators,
+                        property_decorators,
+                    )
 
     # --------------------------- Private Methods -----------------------------
 
     def _get_config_by_discovery(self, node):
         """Get a configuration for checking `node` by config discovery.
-        
+
         Config discovery happens when no explicit config file is specified. The
         file system is searched for config files starting from the directory
         containing the file being checked, and up until the root directory of
         the project.
-        
+
         See `_get_config` for further details.
-        
+
         """
         path = self._get_node_dir(node)
 
@@ -253,13 +394,23 @@ class ConfigurationParser(object):
         else:
             log.debug('Using config file %r', self._run_conf.config)
             if not os.path.exists(self._run_conf.config):
-                raise IllegalConfiguration('Configuration file {!r} specified '
-                                           'via --config was not found.'
-                                           .format(self._run_conf.config))
+                raise IllegalConfiguration(
+                    'Configuration file {!r} specified '
+                    'via --config was not found.'.format(self._run_conf.config)
+                )
+
             if None in self._cache:
                 return self._cache[None]
             options, _ = self._read_configuration_file(self._run_conf.config)
-            config = self._create_check_config(options)
+
+            if options is None:
+                log.warning(
+                    'Configuration file does not contain a '
+                    'pydocstyle section. Using default configuration.'
+                )
+                config = self._create_check_config(self._options)
+            else:
+                config = self._create_check_config(options)
 
         # Make the CLI always win
         final_config = {}
@@ -294,13 +445,19 @@ class ConfigurationParser(object):
         Returns (options, should_inherit).
 
         """
-        parser = RawConfigParser()
+        if path.endswith('.toml'):
+            parser = TomlParser()
+        else:
+            parser = RawConfigParser(inline_comment_prefixes=('#', ';'))
         options = None
         should_inherit = True
 
         if parser.read(path) and self._get_section_name(parser):
-            option_list = dict([(o.dest, o.type or o.action)
-                                for o in self._parser.option_list])
+            all_options = self._parser.option_list[:]
+            for group in self._parser.option_groups:
+                all_options.extend(group.option_list)
+
+            option_list = {o.dest: o.type or o.action for o in all_options}
 
             # First, read the default values
             new_options, _ = self._parse_args([])
@@ -313,7 +470,7 @@ class ConfigurationParser(object):
                     continue
 
                 if opt.replace('_', '-') not in self.CONFIG_FILE_OPTIONS:
-                    log.warning("Unknown option '{}' ignored".format(opt))
+                    log.warning(f"Unknown option '{opt}' ignored")
                     continue
 
                 normalized_opt = opt.replace('-', '_')
@@ -332,7 +489,7 @@ class ConfigurationParser(object):
 
         if options is not None:
             if not self._validate_options(options):
-                raise IllegalConfiguration('in file: {}'.format(path))
+                raise IllegalConfiguration(f'in file: {path}')
 
         return options, should_inherit
 
@@ -352,9 +509,15 @@ class ConfigurationParser(object):
         self._set_add_options(error_codes, child_options)
 
         kwargs = dict(checked_codes=error_codes)
-        for key in ('match', 'match_dir', 'ignore_decorators'):
-            kwargs[key] = \
-                getattr(child_options, key) or getattr(parent_config, key)
+        for key in (
+            'match',
+            'match_dir',
+            'ignore_decorators',
+            'property_decorators',
+        ):
+            kwargs[key] = getattr(child_options, key) or getattr(
+                parent_config, key
+            )
         return CheckConfiguration(**kwargs)
 
     def _parse_args(self, args=None, values=None):
@@ -365,8 +528,9 @@ class ConfigurationParser(object):
     @staticmethod
     def _create_run_config(options):
         """Create a `RunConfiguration` object from `options`."""
-        values = dict([(opt, getattr(options, opt)) for opt in
-                       RunConfiguration._fields])
+        values = {
+            opt: getattr(options, opt) for opt in RunConfiguration._fields
+        }
         return RunConfiguration(**values)
 
     @classmethod
@@ -384,10 +548,18 @@ class ConfigurationParser(object):
             checked_codes = cls._get_checked_errors(options)
 
         kwargs = dict(checked_codes=checked_codes)
-        for key in ('match', 'match_dir', 'ignore_decorators'):
-            kwargs[key] = getattr(cls, 'DEFAULT_{0}_RE'.format(key.upper())) \
-                if getattr(options, key) is None and use_defaults \
+        defaults = {
+            'match': "MATCH_RE",
+            'match_dir': "MATCH_DIR_RE",
+            'ignore_decorators': "IGNORE_DECORATORS_RE",
+            'property_decorators': "PROPERTY_DECORATORS",
+        }
+        for key, default in defaults.items():
+            kwargs[key] = (
+                getattr(cls, f"DEFAULT_{default}")
+                if getattr(options, key) is None and use_defaults
                 else getattr(options, key)
+            )
         return CheckConfiguration(**kwargs)
 
     @classmethod
@@ -410,7 +582,10 @@ class ConfigurationParser(object):
             path = os.path.dirname(path)
 
         for fn in cls.PROJECT_CONFIG_FILES:
-            config = RawConfigParser()
+            if fn.endswith('.toml'):
+                config = TomlParser()
+            else:
+                config = RawConfigParser(inline_comment_prefixes=('#', ';'))
             full_path = os.path.join(path, fn)
             if config.read(full_path) and cls._get_section_name(config):
                 return full_path
@@ -446,14 +621,24 @@ class ConfigurationParser(object):
 
         try:
             for part in code_parts:
-                if len(part) < 4:
-                    for code in codes:
-                        if code.startswith(part):
-                            expanded_codes.add(code)
-                else:
-                    expanded_codes.add(part)
+                # Dealing with split-lined configurations; The part might begin
+                # with a whitespace due to the newline character.
+                part = part.strip()
+                if not part:
+                    continue
+
+                codes_to_add = {
+                    code for code in codes if code.startswith(part)
+                }
+                if not codes_to_add:
+                    log.warning(
+                        'Error code passed is not a prefix of any '
+                        'known errors: %s',
+                        part,
+                    )
+                expanded_codes.update(codes_to_add)
         except TypeError as e:
-            raise IllegalConfiguration(e)
+            raise IllegalConfiguration(e) from e
 
         return expanded_codes
 
@@ -476,28 +661,37 @@ class ConfigurationParser(object):
         was selected.
 
         """
-        for opt1, opt2 in \
-                itertools.permutations(cls.BASE_ERROR_SELECTION_OPTIONS, 2):
+        for opt1, opt2 in itertools.permutations(
+            cls.BASE_ERROR_SELECTION_OPTIONS, 2
+        ):
             if getattr(options, opt1) and getattr(options, opt2):
-                log.error('Cannot pass both {} and {}. They are '
-                          'mutually exclusive.'.format(opt1, opt2))
+                log.error(
+                    'Cannot pass both {} and {}. They are '
+                    'mutually exclusive.'.format(opt1, opt2)
+                )
                 return False
 
         if options.convention and options.convention not in conventions:
-            log.error("Illegal convention '{}'. Possible conventions: {}"
-                      .format(options.convention,
-                              ', '.join(conventions.keys())))
+            log.error(
+                "Illegal convention '{}'. Possible conventions: {}".format(
+                    options.convention, ', '.join(conventions.keys())
+                )
+            )
             return False
         return True
 
     @classmethod
     def _has_exclusive_option(cls, options):
         """Return `True` iff one or more exclusive options were selected."""
-        return any([getattr(options, opt) is not None for opt in
-                    cls.BASE_ERROR_SELECTION_OPTIONS])
+        return any(
+            [
+                getattr(options, opt) is not None
+                for opt in cls.BASE_ERROR_SELECTION_OPTIONS
+            ]
+        )
 
-    @staticmethod
-    def _fix_set_options(options):
+    @classmethod
+    def _fix_set_options(cls, options):
         """Alter the set options from None/strings to sets in place."""
         optional_set_options = ('ignore', 'select')
         mandatory_set_options = ('add_ignore', 'add_select')
@@ -505,10 +699,16 @@ class ConfigurationParser(object):
         def _get_set(value_str):
             """Split `value_str` by the delimiter `,` and return a set.
 
-            Removes any occurrences of '' in the set.
+            Removes empty values ('') and strips whitespace.
+            Also expands error code prefixes, to avoid doing this for every
+            file.
 
             """
-            return set(value_str.split(',')) - {''}
+            if isinstance(value_str, str):
+                value_str = value_str.split(",")
+            return cls._expand_error_codes(
+                {x.strip() for x in value_str} - {""}
+            )
 
         for opt in optional_set_options:
             value = getattr(options, opt)
@@ -530,76 +730,194 @@ class ConfigurationParser(object):
     @classmethod
     def _create_option_parser(cls):
         """Return an option parser to parse the command line arguments."""
-        from optparse import OptionParser
+        from optparse import OptionGroup, OptionParser
 
         parser = OptionParser(
             version=__version__,
-            usage='Usage: pydocstyle [options] [<file|dir>...]')
+            usage='Usage: pydocstyle [options] [<file|dir>...]',
+        )
 
         option = parser.add_option
 
         # Run configuration options
-        option('-e', '--explain', action='store_true', default=False,
-               help='show explanation of each error')
-        option('-s', '--source', action='store_true', default=False,
-               help='show source for each error')
-        option('-d', '--debug', action='store_true', default=False,
-               help='print debug information')
-        option('-v', '--verbose', action='store_true', default=False,
-               help='print status information')
-        option('--count', action='store_true', default=False,
-               help='print total number of errors to stdout')
-        option('--config', metavar='<path>', default=None,
-               help='use given config file and disable config discovery')
+        option(
+            '-e',
+            '--explain',
+            action='store_true',
+            default=False,
+            help='show explanation of each error',
+        )
+        option(
+            '-s',
+            '--source',
+            action='store_true',
+            default=False,
+            help='show source for each error',
+        )
+        option(
+            '-d',
+            '--debug',
+            action='store_true',
+            default=False,
+            help='print debug information',
+        )
+        option(
+            '-v',
+            '--verbose',
+            action='store_true',
+            default=False,
+            help='print status information',
+        )
+        option(
+            '--count',
+            action='store_true',
+            default=False,
+            help='print total number of errors to stdout',
+        )
+        option(
+            '--config',
+            metavar='<path>',
+            default=None,
+            help='use given config file and disable config discovery',
+        )
+
+        parser.add_option_group(
+            OptionGroup(
+                parser,
+                'Note',
+                'When using --match, --match-dir or --ignore-decorators consider '
+                'whether you should use a single quote (\') or a double quote ("), '
+                'depending on your OS, Shell, etc.',
+            )
+        )
+
+        check_group = OptionGroup(
+            parser,
+            'Error Check Options',
+            'Only one of --select, --ignore or --convention can be '
+            'specified. If none is specified, defaults to '
+            '`--convention=pep257`. These three options select the "basic '
+            'list" of error codes to check. If you wish to change that list '
+            '(for example, if you selected a known convention but wish to '
+            'ignore a specific error from it or add a new one) you can '
+            'use `--add-[ignore/select]` in order to do so.',
+        )
+        add_check = check_group.add_option
 
         # Error check options
-        option('--select', metavar='<codes>', default=None,
-               help='choose the basic list of checked errors by '
-                    'specifying which errors to check for (with a list of '
-                    'comma-separated error codes or prefixes). '
-                    'for example: --select=D101,D2')
-        option('--ignore', metavar='<codes>', default=None,
-               help='choose the basic list of checked errors by '
-                    'specifying which errors to ignore (with a list of '
-                    'comma-separated error codes or prefixes). '
-                    'for example: --ignore=D101,D2')
-        option('--convention', metavar='<name>', default=None,
-               help='choose the basic list of checked errors by specifying an '
-                    'existing convention. Possible conventions: {}'
-                    .format(', '.join(conventions)))
-        option('--add-select', metavar='<codes>', default=None,
-               help='amend the list of errors to check for by specifying '
-                    'more error codes to check.')
-        option('--add-ignore', metavar='<codes>', default=None,
-               help='amend the list of errors to check for by specifying '
-                    'more error codes to ignore.')
+        add_check(
+            '--select',
+            metavar='<codes>',
+            default=None,
+            help='choose the basic list of checked errors by '
+            'specifying which errors to check for (with a list of '
+            'comma-separated error codes or prefixes). '
+            'for example: --select=D101,D2',
+        )
+        add_check(
+            '--ignore',
+            metavar='<codes>',
+            default=None,
+            help='choose the basic list of checked errors by '
+            'specifying which errors to ignore out of all of the '
+            'available error codes (with a list of '
+            'comma-separated error codes or prefixes). '
+            'for example: --ignore=D101,D2',
+        )
+        add_check(
+            '--convention',
+            metavar='<name>',
+            default=None,
+            help='choose the basic list of checked errors by specifying '
+            'an existing convention. Possible conventions: {}.'.format(
+                ', '.join(conventions)
+            ),
+        )
+        add_check(
+            '--add-select',
+            metavar='<codes>',
+            default=None,
+            help='add extra error codes to check to the basic list of '
+            'errors previously set by --select, --ignore or '
+            '--convention.',
+        )
+        add_check(
+            '--add-ignore',
+            metavar='<codes>',
+            default=None,
+            help='ignore extra error codes by removing them from the '
+            'basic list previously set by --select, --ignore '
+            'or --convention.',
+        )
+
+        parser.add_option_group(check_group)
 
         # Match clauses
-        option('--match', metavar='<pattern>', default=None,
-               help=("check only files that exactly match <pattern> regular "
-                     "expression; default is --match='{}' which matches "
-                     "files that don't start with 'test_' but end with "
-                     "'.py'").format(cls.DEFAULT_MATCH_RE))
-        option('--match-dir', metavar='<pattern>', default=None,
-               help=("search only dirs that exactly match <pattern> regular "
-                     "expression; default is --match-dir='{}', which "
-                     "matches all dirs that don't start with "
-                     "a dot").format(cls.DEFAULT_MATCH_DIR_RE))
+        option(
+            '--match',
+            metavar='<pattern>',
+            default=None,
+            help=(
+                "check only files that exactly match <pattern> regular "
+                "expression; default is --match='{}' which matches "
+                "files that don't start with 'test_' but end with "
+                "'.py'"
+            ).format(cls.DEFAULT_MATCH_RE),
+        )
+        option(
+            '--match-dir',
+            metavar='<pattern>',
+            default=None,
+            help=(
+                "search only dirs that exactly match <pattern> regular "
+                "expression; default is --match-dir='{}', which "
+                "matches all dirs that don't start with "
+                "a dot"
+            ).format(cls.DEFAULT_MATCH_DIR_RE),
+        )
 
         # Decorators
-        option('--ignore-decorators', metavar='<decorators>', default=None,
-               help=("ignore any functions or methods that are decorated "
-                     "by a function with a name fitting the <decorators> "
-                     "regular expression; default is --ignore-decorators='{0}'"
-                     " which does not ignore any decorated functions."
-                     .format(cls.DEFAULT_IGNORE_DECORATORS_RE)))
+        option(
+            '--ignore-decorators',
+            metavar='<decorators>',
+            default=None,
+            help=(
+                "ignore any functions or methods that are decorated "
+                "by a function with a name fitting the <decorators> "
+                "regular expression; default is --ignore-decorators='{}'"
+                " which does not ignore any decorated functions.".format(
+                    cls.DEFAULT_IGNORE_DECORATORS_RE
+                )
+            ),
+        )
+        option(
+            '--property-decorators',
+            metavar='<property-decorators>',
+            default=None,
+            help=(
+                "consider any method decorated with one of these "
+                "decorators as a property, and consequently allow "
+                "a docstring which is not in imperative mood; default "
+                "is --property-decorators='{}'".format(
+                    cls.DEFAULT_PROPERTY_DECORATORS
+                )
+            ),
+        )
+
         return parser
 
 
 # Check configuration - used by the ConfigurationParser class.
-CheckConfiguration = namedtuple('CheckConfiguration',
-                                ('checked_codes', 'match', 'match_dir',
-                                 'ignore_decorators'))
+CheckConfiguration = namedtuple(
+    'CheckConfiguration',
+    (
+        'checked_codes',
+        'match',
+        'match_dir',
+        'ignore_decorators',
+        'property_decorators',
+    ),
+)
 
 
 class IllegalConfiguration(Exception):
@@ -609,6 +927,7 @@ class IllegalConfiguration(Exception):
 
 
 # General configurations for pydocstyle run.
-RunConfiguration = namedtuple('RunConfiguration',
-                              ('explain', 'source', 'debug',
-                               'verbose', 'count', 'config'))
+RunConfiguration = namedtuple(
+    'RunConfiguration',
+    ('explain', 'source', 'debug', 'verbose', 'count', 'config'),
+)
