@@ -1,4 +1,4 @@
-"""Use tox or py.test to run the test-suite."""
+"""Use tox or pytest to run the test-suite."""
 
 from collections import namedtuple
 
@@ -121,7 +121,7 @@ class SandboxEnv:
         pass
 
 
-@pytest.yield_fixture(scope="module")
+@pytest.fixture(scope="module")
 def install_package(request):
     """Install the package in development mode for the tests.
 
@@ -138,7 +138,7 @@ def install_package(request):
     )
 
 
-@pytest.yield_fixture(scope="function", params=['ini', 'toml'])
+@pytest.fixture(scope="function", params=['ini', 'toml'])
 def env(request):
     """Add a testing environment to a test method."""
     sandbox_settings = {
@@ -621,6 +621,36 @@ def test_overload_function(env):
     assert 'D103' not in out
 
 
+def test_overload_async_function(env):
+    """Async functions decorated with @overload trigger D418 error."""
+    with env.open('example.py', 'wt') as example:
+        example.write(textwrap.dedent('''\
+        from typing import overload
+
+
+        @overload
+        async def overloaded_func(a: int) -> str:
+            ...
+
+
+        @overload
+        async def overloaded_func(a: str) -> str:
+            """Foo bar documentation."""
+            ...
+
+
+        async def overloaded_func(a):
+            """Foo bar documentation."""
+            return str(a)
+
+        '''))
+    env.write_config(ignore="D100")
+    out, err, code = env.invoke()
+    assert code == 1
+    assert 'D418' in out
+    assert 'D103' not in out
+
+
 def test_overload_method(env):
     """Methods decorated with @overload trigger D418 error."""
     with env.open('example.py', 'wt') as example:
@@ -714,6 +744,36 @@ def test_overload_function_valid(env):
     assert code == 0
 
 
+def test_overload_async_function_valid(env):
+    """Valid case for overload decorated async functions.
+
+    This shouldn't throw any errors.
+    """
+    with env.open('example.py', 'wt') as example:
+        example.write(textwrap.dedent('''\
+        from typing import overload
+
+
+        @overload
+        async def overloaded_func(a: int) -> str:
+            ...
+
+
+        @overload
+        async def overloaded_func(a: str) -> str:
+            ...
+
+
+        async def overloaded_func(a):
+            """Foo bar documentation."""
+            return str(a)
+
+        '''))
+    env.write_config(ignore="D100")
+    out, err, code = env.invoke()
+    assert code == 0
+
+
 def test_overload_nested_function(env):
     """Nested functions decorated with @overload trigger D418 error."""
     with env.open('example.py', 'wt') as example:
@@ -1489,3 +1549,25 @@ def test_comment_with_noqa_plus_docstring_file(env):
     out, _, code = env.invoke()
     assert '' == out
     assert code == 0
+
+
+def test_match_considers_basenames_for_path_args(env):
+    """Test that `match` option only considers basenames for path arguments.
+
+    The test environment consists of a single empty module `test_a.py`. The
+    match option is set to a pattern that ignores test_ prefixed .py filenames.
+    When pydocstyle is invoked with full path to `test_a.py`, we expect it to
+    succeed since match option will match against just the file name and not
+    full path.
+    """
+    # Ignore .py files prefixed with 'test_'
+    env.write_config(select='D100', match='(?!test_).+.py')
+
+    # Create an empty module (violates D100)
+    with env.open('test_a.py', 'wt') as test:
+        test.write('')
+
+    # env.invoke calls pydocstyle with full path to test_a.py
+    out, _, code = env.invoke(target='test_a.py')
+    assert '' == out
+    assert code == 0
